from setuptools import find_packages, setup

setup(name = 'rac-test-factorial',
    version = '0.0.3',
    description = "Factorial module.",
    long_description = "A test module for our book.",
    platforms = ["Linux"],
    packages=find_packages()
    )